==> haskell-sayable-1.2.5.0-70.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sayable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sayable
version:              1.2.5.0
visibility:           public
id:                   sayable-1.2.5.0-5PF4c2Zlj2zJNlsGQi1Cv0
key:                  sayable-1.2.5.0-5PF4c2Zlj2zJNlsGQi1Cv0
license:              ISC
copyright:            Galois Inc., 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Construction of context-adjusted pretty output
description:

    This package provides a set of data structures, classes and operators that
    facilitate the construction of a Prettyprinter Doc object.  The difference
    between this an Prettyprinter is:

    * Additional "saytag" parameter that can be used to control the Doc rendering.

    * Brevity of syntax (using operators) designed to enhance conversion of
    arguments and readability of messages and conversion

category:             Text
abi:                  548999f68d26a7802b203c34d0c925d4
exposed:              True
exposed-modules:      Text.Sayable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sayable-1.2.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sayable-1.2.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sayable-1.2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sayable
hs-libraries:         HSsayable-1.2.5.0-5PF4c2Zlj2zJNlsGQi1Cv0
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    template-haskell-2.20.0.0 text-2.0.2
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:   /usr/share/doc/haskell-sayable/html/sayable.haddock
haddock-html:         /usr/share/doc/haskell-sayable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sayable-1.2.6.0-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sayable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sayable
version:              1.2.6.0
visibility:           public
id:                   sayable-1.2.6.0-Fuydsx71HXZJrlJ9X45bN1
key:                  sayable-1.2.6.0-Fuydsx71HXZJrlJ9X45bN1
license:              ISC
copyright:            Galois Inc., 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Construction of context-adjusted pretty output
description:

    This package provides a set of data structures, classes and operators that
    facilitate the construction of a Prettyprinter Doc object.  The difference
    between this an Prettyprinter is:

    * Additional "saytag" parameter that can be used to control the Doc rendering.

    * Brevity of syntax (using operators) designed to enhance conversion of
    arguments and readability of messages and conversion

category:             Text
abi:                  e117386cdfc7a26c37376e3224787aa1
exposed:              True
exposed-modules:      Text.Sayable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sayable-1.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sayable
hs-libraries:         HSsayable-1.2.6.0-Fuydsx71HXZJrlJ9X45bN1
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    template-haskell-2.20.0.0 text-2.0.2
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:   /usr/share/doc/haskell-sayable/html/sayable.haddock
haddock-html:         /usr/share/doc/haskell-sayable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
